<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d veza';
$lang['%d associations'] = '%d veze';
$lang['%d album including'] = '%d kategorija obuhvata ';
$lang['%d albums including'] = '%d kategorije obuhvataju ';
$lang['%d physical'] = '%d stvarna';
$lang['%d physicals'] = '%d stvarnih';
$lang[' and %d virtual'] = ' i %d virtualna';
$lang[' and %d virtuals'] = ' i %d virtualnih';
$lang['%d album moved'] = '%d kategorija premeštena';
$lang['%d albums moved'] = '%d kategorija premešteno';
$lang['%d group'] = '%d grupa';
$lang['%d groups'] = '%d grupa';
$lang['%d member'] = '%d član';
$lang['%d members'] = '%d članova';
$lang['%d tag'] = '%d oznaka';
$lang['%d tags'] = '%d oznaka';
$lang['%d user comment rejected'] = '%d korisnički komentar odbačen';
$lang['%d user comments rejected'] = '%d korisničkih komentara odbačeno';
$lang['%d user comment validated'] = '%d korisnički kometar odobren';
$lang['%d user comments validated'] = '%d korisničkih komentara odobreno';
$lang['%d user deleted'] = '%d korisnik izbrisan';
$lang['%d users deleted'] = '%d korisnika izbrisano';
$lang['%d user'] = '%d korisnik';
$lang['%d users'] = '%d korisnika';
$lang['%d waiting for validation'] = '%d čekanje na overu';
$lang['Actions'] = 'Postupci';
$lang['Activate'] = 'Uključi';
$lang['Add/delete a permalink'] = 'Dodaj/izbriši stalnu vezu';
$lang['Add a tag'] = 'Dodaj';
$lang['Add a user'] = 'Dodaj korisnika';
$lang['Add group'] = 'Dodaj grupu';
$lang['Add'] = 'Dodaj';
$lang['Allow user registration'] = 'Odobri upis korisnika';
$lang['Apply to sub-albums'] = 'Primeni na podkategorije';
$lang['Associated'] = 'Povezanost';
$lang['Caddie management'] = 'Kontrola fioke';
$lang['Caddie'] = 'Fioka';
$lang['Albums authorized thanks to group associations'] = 'Kategorije overene zahvaljujući grupnoj vezi';
$lang['Album manual order was saved'] = 'Redosled kategorija je sačuvan';
$lang['Check for upgrade failed for unknown reasons.'] = 'Provera nadogradnje neuspešna iz nepoznatog razloga.';
$lang['Check for upgrade'] = 'Provera nadogradnje';
$lang['Comments for all'] = 'Komentari za sve';
$lang['Current name'] = 'Trenutni naziv';
$lang['Database'] = 'Baza podataka';
$lang['Deactivate'] = 'Isključi';
$lang['Deletions'] = 'Brisanja';
$lang['Deny selected groups'] = 'Zabrani odabrane grupe';
$lang['Deny selected users'] = 'Zabrani odabrane korisnike';
$lang['Description'] = 'Opis';
$lang['Display options'] = 'Mogućnosti prikaza';
$lang['Dissociated'] = 'Odvojeno';
$lang['Does not represent'] = 'Ne predstavlja';
$lang['Edit selected tags'] = 'Uredi odabrane oznake';
$lang['Edit tags'] = 'Uredi oznake';
$lang['Email admins when a new user registers'] = 'E-mail administratorima pri upisu novih korisnika';
$lang['Email admins when a valid comment is entered'] = 'E-mail administratorima pri upisu novih komentara';
$lang['Email admins when a comment requires validation'] = 'Email administratorima kada komentar treba overu';
$lang['Environment'] = 'Okruženje';
$lang['Form'] = 'Oblik';
$lang['Gallery title'] = 'Naziv galerije';
$lang['Grant selected groups'] = 'Ovlasti odabrane grupe';
$lang['Grant selected users'] = 'Ovlasti odabrane korisnike';
$lang['Group name'] = 'Naziv grupe';
$lang['Groups'] = 'Grupa';
$lang['Guests'] = 'Gostiju';
$lang['History'] = 'Istorija';
$lang['Informations'] = 'Informacije';
$lang['Install'] = 'Instaliraj';
$lang['Link all album photos to a new album'] = 'Poveži sve elemente kategorije sa novom kategorijom';
$lang['Link all album photos to some existing albums'] = 'Poveži sve elemente kategorije sa nekom postojećom kategorijom';
$lang['Linked albums'] = 'Povezane kategorije';
$lang['Lock gallery'] = 'Zaključaj galeriju';
$lang['Maintenance'] = 'Održavanje';
$lang['Edit album permissions'] = 'Upravljanje dozvolama za kategoriju';
$lang['Manage permissions for group "%s"'] = 'Upravljanje dozvolama za grupu "%s"';
$lang['Manage permissions for user "%s"'] = 'Upravljanje dozvolama za korisnika "%s"';
$lang['Manage tags'] = 'Upravljanje oznakama';
$lang['Members'] = 'Članovi';
$lang['Metadata synchronized from file'] = 'Usklađivanje meta podataka iz datoteke';
$lang['Move albums'] = 'Premesti kategorije';
$lang['Move'] = 'Premesti';
$lang['Name'] = 'Naziv';
$lang['New name'] = 'Novi naziv';
$lang['New parent album'] = 'Nova nadređena kategorija';
$lang['New tag'] = 'Nova oznaka';
$lang['Number of comments per page'] = 'Broj komentara po stranici';
$lang['Number of rates'] = 'Broj ocena';
$lang['Number of thumbnails to create'] = 'broj poveznih sličica za izradu';
$lang['Only private albums are listed'] = 'Samo lične kategorije su ispisane';
$lang['Operating system'] = 'Operativni sistem';
$lang['Options'] = 'Mogućnosti';
$lang['Other private albums'] = 'Ostale lične kategorije';
$lang['Page banner'] = 'Baner stranice';
$lang['Parent album'] = 'Nadređena kategorija';
$lang['Path'] = 'Putanja';
$lang['Permalink'] = 'Stalna veza';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Stalna veza mora biti sastavljena od znakova a-z, A-Z, 0-9, "-", "_" ili "/". Ne sme biti brojčana vrijednost ili počinjati brojem pa znakom "-"';
$lang['Permalink %s is already used by album %s'] = 'Stalnu vezu %s već koristi kategorija %s';
$lang['Permalink history'] = 'Istorija stalnih veza';
$lang['Permalinks'] = 'Stalne veze';
$lang['Permission denied'] = 'Dozvola uskraćena';
$lang['Permission granted thanks to a group'] = 'Dozvola odobrena zahvaljujući grupi';
$lang['Permission granted'] = 'Dozvola odobrena';
$lang['Photo informations updated'] = 'Podaci o slikama obnovljeni';
$lang['Plugins'] = 'Dodaci';
$lang['Position'] = 'Položaj';
$lang['Preferences'] = 'Podešavanja';
$lang['Properties'] = 'Karakteristike';
$lang['Random photo'] = 'Slika slučajnog izbora';
$lang['Rate date'] = 'Datum ocene';
$lang['Rating by guests'] = 'Ocene gostiju';
$lang['Rating'] = 'Ocenjivanje';
$lang['Reject'] = 'Odbaci';
$lang['Representant'] = 'Predstavnik';
$lang['Representation of albums'] = 'Predstavljanje kategorija';
$lang['Representative'] = 'Predstavljeno';
$lang['Represents'] = 'Predstavlja';
$lang['Save order'] = 'Snimi raspored';
$lang['Save to permalink history'] = 'Snimi u istoriju stalnih veza';
$lang['Select at least one album'] = 'Odaberite najmanje jednu kategoriju';
$lang['Select at least one photo'] = 'Odaberite najmanje jednu sliku';
$lang['Select at least one user'] = 'Odaberite najmanje jednog korisnika';
$lang['Show info'] = 'Prikaz podataka';
$lang['Site manager'] = 'Administrator galerije';
$lang['Status'] = 'Stanje';
$lang['Statistics'] = 'Statistika';
$lang['Storage album'] = 'Kategorija snimanja';
$lang['Sum of rates'] = 'Zbir ocena';
$lang['Tag "%s" already exists'] = 'Oznaka "%s" već postoji';
$lang['Tag "%s" was added'] = 'Oznaka "%s" dodata';
$lang['Tag selection'] = 'Izbor oznake';
$lang['The %d following tags were deleted'] = 'Sledeće %d oznake su izbrisane';
$lang['Unable to check for upgrade.'] = 'Ne mogu proveriti za nadogradnju.';
$lang['Uninstall'] = 'Ukloni';
$lang['Use the default photo sort order'] = 'Koristi podrazumevani redosled slaganja slika';
$lang['User comments validation'] = 'Overa korisničkih komentara';
$lang['Users'] = 'Korisnici';
$lang['Validate'] = 'Overi';
$lang['Validation'] = 'Overa';
$lang['Version'] = 'Verzija';
$lang['Virtual albums to move'] = 'Virtuelne kategorije za premeštanje';
$lang['Virtual album name'] = 'Naziv virtuelne kategorije';
$lang['Webmaster cannot be deleted'] = 'Webmaster ne može biti izbrisan';
$lang['You are running on development sources, no check possible.'] = 'Vi koristite razvojni izvorni kod, provera nemoguća.';
$lang['You cannot delete your account'] = "Ne možete izbrisati svoj nalog";
$lang['You cannot move an album in its own sub album'] = 'Ne možete premestiti kategoriju u njenu podkategoriju';
$lang['You need to confirm deletion'] = 'Potvrdi brisanje';
$lang['Associate to album'] = 'poveži sa kategorijom';
$lang['associate to group'] = 'poveži sa grupom';
$lang['Authorized'] = 'Ovlašćeno';
$lang['Add a virtual album'] = 'Dodaj virtuelnu kategoriju';
$lang['Authorize users to add comments on selected albums'] = 'Ovlastite korisnike za davanje komentara u odabranim kategorijama';
$lang['The name of an album must not be empty'] = 'Naziv kategorije ne bi trebao biti prazan';
$lang['Lock albums'] = 'Zaključaj kategorije';
$lang['Private'] = 'Lična kategorija';
$lang['Public'] = 'Javna kategorija';
$lang['Find a new representant by random'] = 'Izbor novog predstavnika slučajnim izborom';
$lang['Public / Private'] = 'Javno / Lično';
$lang['Manage authorizations for selected albums'] = 'Upravljanje ovlašćenjima za odabrane kategorije';
$lang['Virtual album added'] = 'Virtuelna kategorija dodata';
$lang['Virtual album deleted'] = 'Virtuelna kategorija izbrisana';
$lang['Access type'] = 'Vrsta pristupa';
$lang['Information data registered in database'] = 'Podaci upisani u bazu podataka';
$lang['Default display'] = 'Podrazumevani prikaz';
$lang['The gallery URL is not valid.'] = 'URL galerije nije odgovarajući.';
$lang['Main'] = 'Glavno';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Broj komentara po stranici mora biti između 5 i 50.';
$lang['Configuration'] = 'Podešavanje';
$lang['confirm'] = 'potvrdi';
$lang['Date'] = 'Datum';
$lang['delete album'] = 'obriši kategoriju';
$lang['Dissociate from album'] = 'odvoji od kategorije';
$lang['dissociate from group'] = 'odvoji od grupe';
$lang['Album updated successfully'] = 'Podaci kategorije uspešno obnovljeni.';
$lang['photos per page'] = 'elemenata po stranici';
$lang['High definition enabled'] = 'Visoka rezolucija omogućena';
$lang['File'] = 'Datoteka';
$lang['first photo added on %s'] = 'prvi element dodat %s';
$lang['Forbidden'] = 'Zabranjeno';
$lang['global mode'] = 'opšti način';
$lang['group "%s" added'] = 'grupa "%s" dodata';
$lang['group "%s" deleted'] = 'grupa "%s" izbrisana';
$lang['group "%s" updated'] = 'grupa "%s" obnovljena';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Naziv grupe ne može sadržati  " ili \' ili biti prazan.';
$lang['This name is already used by another group.'] = 'Ovaj naziv već koristi druga grupa.';
$lang['High definition'] = 'Visoka rezolucija';
$lang['jump to album'] = 'skok u kategoriju';
$lang['jump to photo'] = 'skok na sliku';
$lang['leave'] = 'ostavi';
$lang['Lock'] = 'Zaključaj';
$lang['Locked'] = 'Zaključano';
$lang['manage album photos'] = 'upravljanje elementima kategorije';
$lang['manage sub-albums'] = 'upravljanje podkategorijama';
$lang['Manage'] = 'Upravljaj';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Vreme izvršenja je isteklo, obrada se mora nastaviti [Procenjeno vreme: %d sekunde].';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Vreme izvršenja je isteklo, obrada se mora nastaviti [Procenjeno vreme: %d sekundi].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Predviđeno vreme za popis korisnika za slanje poruka je ograničeno. Ostali korisnici nisu izlistani.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Vreme za slanje poruke je ograničeno. Ostale poruke su preskočene.';
$lang['To send ?'] = 'Poslati ?';
$lang['Last send'] = 'Zadnje poslato';
$lang['Email'] = 'e-mail';
$lang['User'] = 'Korisnik';
$lang['See you soon,'] = 'Vidimo se uskoro,';
$lang['Go to'] = 'Idi na ';
$lang['Hello'] = 'Pozdrav ';
$lang['New photos were added'] = 'Novi elementi su dodati ';
$lang['on'] = ' na ';
$lang['between'] = 'između ';
$lang['and'] = ' i ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Webmaster vas je pretlatio na primanje e-mail obaveštenja.';
$lang['You have subscribed to receiving notifications by mail.'] = 'Pretplatili ste se na primanje e-mail obaveštenja.';
$lang['To subscribe'] = 'Pretplata';
$lang['If you encounter problems or have any question, please send a message to'] = 'Ukoliko ste naišli na probleme ili imate pitanja, molimo pošaljite poruku za ';
$lang['[NBM] Problems or questions'] = '[NBM] Problemi ili pitanja';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Webmaster Vas je uklonio sa liste za primanje e-mail obaveštenja.';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Uklonili ste se sa liste za primanje e-mail obaveštenja.';
$lang[', click on'] = ', kliknite na ';
$lang['To unsubscribe'] = 'Za uklanjanje';
$lang['With blank value, gallery title will be used'] = 'Sa praznim poljem, koristi će se naziv galerije';
$lang['Notification'] = 'Obaveštenje';
$lang['Error when sending email to %s [%s].'] = 'Greška prilikom slanja e-mail poruke za %s [%s].';
$lang['Mail sent to %s [%s].'] = 'Poruka poslata za %s [%s].';
$lang['%d mail was sent.'] = '%d poruka poslata.';
$lang['%d mails were sent.'] = '%d poruke poslate.';
$lang['%d mail was not sent.'] = '%d poruka nije poslata.';
$lang['%d mails were not sent.'] = '%d poruke nisu poslate.';
$lang['No mail to send.'] = 'Nema poruke za slanje.';
$lang['There is no available subscribers to mail.'] = 'Nema dostupnih primaoca za slanje poruka.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Pretplatnici mogu biti izlistani (dostupni) samo ako ima novih elemenata za obaveštenje.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'U svakom slučaju samo webmaster može pristupiti ovoj tabli a nikad administratori.';
$lang['No user to send notifications by mail.'] = 'Nema korisnika za slanje e-mail obaveštenja.';
$lang['New photos added'] = 'Novi elementi dodati';
$lang['Subscribe to notification by mail'] = 'Pretplatite se za e-mail obaveštenja';
$lang['Unsubscribe from notification by mail'] = 'Uklonite se iz sistema primanja e-mail obaveštenja';
$lang['Parameter'] = 'Stavka';
$lang['Continue processing treatment'] = 'Nastavi obradu postupka';
$lang['Complementary mail content'] = 'Kompletan sadržaj poruke';
$lang['Add detailed content'] = 'Dodaj detaljni sadržaj';
$lang['Send mail as'] = 'Pošalji poruku kao ';
$lang['Send mail to users'] = 'Pošalji poruku korisnicima';
$lang['Send'] = 'Pošalji';
$lang['Options'] = 'Mogućnosti';
$lang['Send'] = 'Pošalji';
$lang['Subscribed'] = 'Pretplaćen';
$lang['Subscribe'] = 'Pretplatite se';
$lang['Parameters'] = 'Stavke';
$lang['Select recipients'] = 'Odaberite primaoce';
$lang['Subscribe/unsubscribe users'] = 'Pretplati/poništi pretplatu korisnika';
$lang['Unsubscribed'] = 'Pretplata poništena';
$lang['%d parameter was updated.'] = '%d stavka je obnovljena.';
$lang['%d parameters were updated.'] = '%d stavke su poništene.';
$lang['%d user was not updated.'] = '%d korisnik nije obnovljen.';
$lang['%d users were not updated.'] = '%d korisnici nisu obnovljeni.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Korisnik %s [%s] je uklonjen iz liste pretplatnika.';
$lang['User %s [%s] was added to the subscription list.'] = 'Korisnik %s [%s] je dodat na listu pretplatnika.';
$lang['%d user was updated.'] = '%d korisnik je obnovljen.';
$lang['%d users were updated.'] = '%d korisnici su obnovljeni.';
$lang['User %s [%s] was not removed from the subscription list.'] = 'Korisnik %s [%s] nije uklonjen iz liste pretplatnika.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Korisnik %s [%s] nije dodat na listu pretplatnika.';
$lang['User %s [%s] added.'] = 'Korisnik %s [%s] dodat.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'Upozorenje: pretplata ili ukidanje pretplate će poslati e-mail poruke korisnicima';
$lang['Send mail on HTML format'] = 'Pošalji poruku u HTML obliku';
$lang['Include display of recent photos grouped by dates'] = 'Uključi prikaz nedavnih slika složenih po datumima';
$lang['Available only with HTML format'] = 'Dostupno samo u HTML obliku';
$lang['no write access'] = 'nema dozvole upisa';
$lang['Permissions'] = 'Dozvole';
$lang['private'] = 'lično';
$lang['public'] = 'javno';
$lang['Purge never used notification feeds'] = 'Isprazni nikad korišćene obaeštavajuće izvore';
$lang['Purge sessions'] = 'Isprazni sesije';
$lang['randomly represented'] = 'predstavljen slučajnim izborom';
$lang['registration date'] = 'datum upisa';
$lang['clean'] = 'čisto';
$lang['Create this site'] = 'Napravi ovu stranicu';
$lang['test'] = 'proba';
$lang['test this remote site'] = 'isprobajte ovo udaljenu stranicu';
$lang['remove tags'] = 'ukloni oznake';
$lang['Repair and optimize database'] = 'Popravi i podesi bazu podataka';
$lang['selection'] = 'izbor';
$lang['set to'] = 'postavljeno na';
$lang['singly represented'] = 'jednoznačno predstavljeno';
$lang['This site already exists'] = 'Ova stranica već postoji';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Izradi novu stranicu : (odrdite njenu URL za izradu create_listing_file.php)';
$lang['created'] = 'napravljeno';
$lang['delete'] = 'obriši';
$lang['delete this site and all its attached elements'] = 'obriši ovu stranicu i sve njene pridodate stavke';
$lang['an error happened'] = 'došlo je do greške';
$lang['Local'] = 'Lokalno';
$lang['Remote'] = 'Udaljeno';
$lang['update the database from files'] = 'obnovi bazu podataka pomoću datoteke';
$lang['status'] = 'stanje';
$lang['Directory'] = 'Mapa';
$lang['sub-albums'] = 'podkategorije';
$lang['Synchronize metadata'] = 'sinhronizuj meta podatke';
$lang['target'] = 'odredište';
$lang['Thumbnail'] = 'Povezne sličice';
$lang['Title'] = 'naslov';
$lang['Album list management'] = 'Upravljanje kategorijama';
$lang['Piwigo configuration'] = 'Piwigo podešavanja';
$lang['Edit album'] = 'Uredi kategoriju';
$lang['Group management'] = 'Upravljanje grupama';
$lang['User list'] = 'Lista korisnika';
$lang['Database synchronization with files'] = 'Sinhronizacija baze podataka sa datotekama';
$lang['all'] = 'sve';
$lang['height must be a number superior to'] = 'visina mora biti broj veći od ';
$lang['width must be a number superior to'] = 'širina mora biti broj veći od';
$lang['for the file format'] = 'za datotečni oblik';
$lang['Photo unreachable or no support'] = 'Slika nedostupna ili bez podrške';
$lang['GD version'] = 'GD verzija';
$lang['General statistics'] = 'Glavna statistika';
$lang['average time'] = 'prosečno vreme';
$lang['number of miniaturized photos'] = 'broj umanjenih slika';
$lang['total time'] = 'ukupno vreme';
$lang['for this file format'] = 'za ovu vrstu datoteke';
$lang['unit mode'] = 'pojedinačni način';
$lang['Unlocked'] = 'Otključano';
$lang['unset'] = 'razdešeno';
$lang['Update albums informations'] = 'Obnovi podatke o kategorijama';
$lang['Update photos information'] = 'Obnovi podatke o slikama';
$lang['Synchronize'] = 'Sinhronizuj';
$lang['reduce to single existing albums'] = 'umanji na jednu postojeću kategoriju-e';
$lang['Choose an option'] = 'Izaberite mogućnost';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'najopširniji mogući prikaz podataka (dodate kategorije i elementi, izbrisane  kategorije i elementi)';
$lang['Error list'] = 'Lista grešaka ';
$lang['Errors caption'] = 'Zaglavlja grešaka';
$lang['Detailed informations'] = 'Detaljnija obaveštenja';
$lang['File/directory read error'] = 'Greška čitanja datoteke/direktorijuma';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Datoteci ili direktorijumu se ne može pristupiti (ne postoji ili je pristup zabranjen)';
$lang['albums deleted in the database'] = 'kategorije izbrisane iz baze podataka';
$lang['photos deleted from the database'] = 'elementi izbrisani iz baze podataka';
$lang['photos candidates for metadata synchronization'] = 'slika kandidata za sinhronizaciju meta podataka';
$lang['photos informations synchronized with files metadata'] = 'podataka elemenata sinhronizovano sa meta podacima datoteke';
$lang['errors during synchronization'] = 'grešaka tokom sinhronizacije';
$lang['albums added in the database'] = 'kategorija dodato u bazu podataka';
$lang['photos added in the database'] = 'elemenata dodato u bazu podataka';
$lang['photos updated in the database'] = 'elemenata obnovljeno u bazi podataka';
$lang['Search for new images in the directories'] = 'Pretraživanje novih slika u direktorijumima';
$lang['added'] = 'dodato';
$lang['deleted'] = 'obrisano';
$lang['Metadata synchronization results'] = 'Rezultat usklađivanja meta podataka';
$lang['only perform a simulation (no change in database will be made)'] = 'izvrši samo simulaciju (nema promena u bazi podataka)';
$lang['Simulation'] = 'Simulacija';
$lang['directories + files'] = 'direktorijume + datoteke';
$lang['only directories'] = 'samo direktorijume';
$lang['synchronize files structure with database'] = 'uskladi strukturu datoteke sa bazom podataka';
$lang['synchronize files metadata with database photos informations'] = 'uskladi meta podatke datoteke sa podacima o elementu iz baze podataka';
$lang['even already synchronized photos'] = 'čak i već usklađene elemente';
$lang['Used metadata'] = 'Korišćeni meta podaci';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Nazivi direktorijuma i datoteka moraju biti sastavljeni od slova, brojva, "-", "_" ili "."';
$lang['wrong filename'] = 'loš naziv datoteke';
$lang['Upload'] = 'Prebaci';
$lang['user "%s" added'] = 'korisnik "%s" dodat';
$lang['User status'] = 'Stanje korisnika';
$lang['user_status_admin'] = 'Administrator';
$lang['user_status_generic'] = 'Opšti';
$lang['user_status_guest'] = 'Gost';
$lang['user_status_normal'] = 'Korisnik';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Virtuelna ketegorija';
$lang['Waiting'] = 'Čekanje';
$lang['default'] = 'podrazumevano';
$lang['Toggle \'default group\' property'] = 'Promeni \'podrazumevana grupa\' osobine';
$lang['Advanced features'] = 'Napredne mogućnosti';
$lang['Overall'] = 'Sveukupno';
$lang['Year'] = 'Godina';
$lang['Month'] = 'Mesec';
$lang['Day'] = 'Dan';
$lang['Pages seen'] = 'Stranica viđeno';
$lang['Time'] = 'Vreme';
$lang['IP'] = 'IP';
$lang['Element'] = 'Element';
$lang['Section'] = 'Sekcija';
$lang['An information email was sent to group "%s"'] = 'E-mail poruka obaveštenja je poslata grupi "%s';
$lang['Send an information email to group members'] = 'Pošalji e-mail obaveštenja članovima grupe';
$lang['Group'] = 'Grupa';
$lang['[%s] Visit album %s'] = '[%s] Dođite i pogledajte kategoriju %s';
$lang['Hello,'] = 'Zdravo,';
$lang['See you soon.'] = 'Do viđenja.';
$lang['Discover album:'] = 'Dođite i otkrijte kategoriju:';
$lang['Mail content'] = 'sadržaj e-mail poruke';
$lang['none'] = 'ni jedan';
$lang['high'] = 'visoko';
$lang['other'] = 'ostalo';
$lang['Element type'] = 'Tip elementa';
$lang['Image id'] = 'ID slike';
$lang['Summary'] = 'Zbirno';
$lang['%d line filtered'] = '%d linija pročišćena';
$lang['%d lines filtered'] = '%d linija pročišćeno';
$lang['%d guest'] = '%d gost';
$lang['%d guests'] = '%d gostiju';
$lang['Hour'] = 'Sat';
$lang['guest'] = 'gost';
$lang['default values'] = 'podrazumevane vrednosti';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'Gost ne može biti izbrisan';
$lang['Default user cannot be deleted'] = 'Podrazumevani korisnik ne može biti izbrisan';
$lang['Purge history detail'] = 'Isprazni detalje istorije';
$lang['Purge history summary'] = 'Isprazni zbirnu istoriju';
$lang['Check integrity'] = 'Provera celovitosti';
$lang['Anomaly'] = 'Nepravilnost';
$lang['Correction'] = 'Ispravka';
$lang['Automatic correction'] = 'Automatsko ispravljanje';
$lang['Impossible automatic correction'] = 'Automatsko ispravljanje nemoguće';
$lang['Correction applied with success'] = 'Ispravka uspešno primenjena';
$lang['Correction applied with error'] = 'Ispravka primenjena s greškom';
$lang['%d anomaly has been detected.'] = '%d nepravilnost je otkrivena.';
$lang['%d anomalies have been detected.'] = '%d nepravilnosti su otkrivene.';
$lang['%d anomaly has been corrected.'] = '%d nepravilnost je ispravljena.';
$lang['%d anomalies have been detected corrected.'] = '%d nepravilnosti je ispravljeno.';
$lang['%d anomaly has not been corrected.'] = '%d nepravilnost nije ispravljena.';
$lang['%d anomalies have not been corrected.'] = '%d nepravilnosti nije ispravljeno.';
$lang['Go to %s or %s for more informations'] = 'Idite na %s ili %s za više detalja';
$lang['the forum'] = 'forum';
$lang['the wiki'] = 'wiki';
$lang['%s value is not correct file because exif are not supported'] = '%s vrijednost nije valjana datoteka jer exif nije podržan';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s mora biti postavljeno na false u config_local.inc.php file';
$lang['Main "guest" user does not exist'] = 'Glavni "guest" korisnik ne postoji';
$lang['Main "guest" user status is incorrect'] = 'Stanje glavnog "guest" korisnika je neispravno';
$lang['Default user does not exist'] = 'Podrazumevani korisnik ne postoji';
$lang['Main "webmaster" user does not exist'] = 'Glavni "webmaster" korisnik ne postoji';
$lang['Main "webmaster" user status is incorrect'] = 'Stanje glavnog "webmaster" korisnika je neispravno';
$lang['User "%s" created with "%s" like password'] = 'Korisnik "%s" izrađen sa "%s" kao lozinkom';
$lang['Status of user "%s" updated'] = 'Stanje korisnika "%s" obnovljeno';
$lang['add new photos to caddie'] = 'dodaj nove elemente u fioku';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = 'Bez prikaza';
$lang['Classic display'] = 'Klasični prikaz';
$lang['Hoverbox display'] = 'Prikaz lebdećim prozorom';
$lang['Mail address is obligatory for all users'] = 'E-mail adresa je obavezna za sve korisnike';
$lang['Minimum privacy level'] = 'Najniži nivo privatnosti';
$lang['Privacy level'] = 'Nivo privatnosti';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Poznanici';
$lang['Level 2'] = 'Prijatelji';
$lang['Level 4'] = 'Porodica';
$lang['Level 8'] = 'Administratori';
$lang['Reinitialize check integrity'] = 'Ponovi proveru celovitosti';
$lang['Check all'] = 'Označi sve';
$lang['Uncheck all'] = 'Odznači sve';
$lang['Check automatic corrections'] = 'Označi automatske ispravke';
$lang['Apply selected corrections'] = 'Primeni odabrane ispravke';
$lang['Ignore selected anomalies'] = 'Zanemari odabrane nepravilnosti';
$lang['Refresh'] = 'Osveži';
$lang['The anomaly will be ignored until next application version'] = 'Nepravilnost će se zanemariti do sledeće verzije galerije';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Ispravka nepravilnosti će poništiti činjenicu da je zanemarena';
$lang['%d anomaly has been ignored.'] = '%d nepravilnost je zanemarena.';
$lang['%d anomalies have been ignored.'] = '%d nepravilnosti su zanemarene.';
$lang['Plugins which need upgrade'] = 'Dodaci koji trebaju nadogradnju';
$lang['Plugin list'] = 'Lista dodataka';
$lang['Check for updates'] = 'Provera nadogradnje';
$lang['Other plugins'] = 'Ostali dodaci';
$lang['Last revisions'] = 'Zadnja izdanja';
$lang['Are you sure you want to delete this plugin?'] = 'Sigurno želite ukloniti ovaj dodatak?';
$lang['Are you sure you want to install this plugin?'] = 'Sigurno želite instalirati ovaj dodatak?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Sigurno želite instalirati ovaj dodatak? Morate potvrditi da ova prečica ne treba uklanjanje.';
$lang['Plugin has been successfully copied'] = 'Dodatak je uspješno iskopiran';
$lang['You might go to plugin list to install and activate it.'] = 'Možete ići na listu datoteka za instalaciju i pokretanje.';
$lang['Can\'t create temporary file.'] = 'Ne mogu napraviti privremeni datoteku.';
$lang['Can\'t download archive.'] = 'Ne mogu preuzeti datoteku.';
$lang['Can\'t read or extract archive.'] = 'Ne mogu očitati ili raspakovati datoteku.';
$lang['An error occured during extraction (%s).'] = 'Došlo je do greške prilikom raspakovanja (%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Proverite "plugins" direktorijum i dozvole poddirektorijuma (CHMOD).';
$lang['Can\'t connect to server.'] = 'Ne mogu se povezati na server.';
$lang['Purge compiled templates'] = 'Isprazni obrađene šablone';
$lang['ACCESS_0'] = 'Slobodan pristup';
$lang['ACCESS_1'] = 'Pristup svima';
$lang['ACCESS_2'] = 'Pristup pretplatnicima';
$lang['ACCESS_3'] = 'Pristup administratorima';
$lang['ACCESS_4'] = 'Pristup webmaster-ima';
$lang['ACCESS_5'] = 'Bez pristupa';
$lang['Support'] = 'Podrška';
$lang['Documentation'] = 'Dokumentacija';
$lang['A new version of Piwigo is available.'] = 'Nova Piwigo verzija je dostupna.';
$lang['Piwigo Administration'] = 'Piwigo administracija';
$lang['Piwigo version'] = 'Piwigo verzija';
$lang['You are running the latest version of Piwigo.'] = 'Koristite najnoviju verziju Piwigo-a.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Verzija od %s [%s] postavljene nije odgovarajuća potrebnoj verziji [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'morate nadograditi vaš sistem da biste imali sve pogodnosti u protivnom sistem neće raditi ispravno ili uopšte neće raditi';
$lang['Deleted on'] = 'Izbrisan na';
$lang['Last hit'] =  'Zadnja poseta';
$lang['GD library is missing'] = 'Nedostaje GD biblioteka';
$lang['Templates'] = 'Šabloni';
$lang['Extend for templates'] = 'Proširenje za šablone';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] =
 'Zamena izvornih šablona prilagođenim iz direktorijuma template-extension';
$lang['Replacers (customized templates)'] = 'Zamene (prilagođeni šabloni)';
$lang['Original templates'] = 'Izvorni šabloni';
$lang['Optional URL keyword'] = 'Izborna URL ključna reč';
$lang['Templates configuration has been recorded.'] = 'Podešavnje šablona je sačuvano.';
$lang['All optimizations have been successfully completed.'] = 'Sva poboljšanja su uspešno dovršena.';
$lang['Optimizations have been completed with some errors.'] = 'Poboljšanja su izvršena uz neke greške.';
$lang['Modify information'] = 'Promeni podatak';
$lang['nothing'] = 'ništa';
$lang['overrides existing values with empty ones'] = 'prekucava postojeće vrednosti praznim poljima';
$lang['Manage photo ranks'] = 'Upravljanje poretkom';
$lang['Edit ranks'] = 'Uredi poredak';
$lang['No photo in this album'] = 'Nema elemenata u ovoj kategoriji';
$lang['Images manual order was saved'] = 'Sačuvan je podešenii redosled slika';
$lang['ranks'] = 'poredak';
$lang['Drag to re-order'] = 'Povuci za preređivanje';
$lang['Quick Local Synchronization'] = 'Brza Lokalna Sinhronizacija';
$lang['No photo can be deleted'] = 'Nema slike koja se može brisati';
$lang['Delete selected photos'] = 'Briši odabrane slike';
$lang['%d photo was deleted'] = '%d slika je izbrisana';
$lang['%d photos were deleted'] = '%d slike su izbrisane';
$lang['Downloads'] = 'Preuzimanja';
$lang['Released on'] = 'Objavljeno dana';
$lang['Number of downloads'] = 'Broj preuzimanja';
// --------- Starting below: New or revised $lang ---- from Colibri
$lang['Piwigo Announcements Newsletter'] = 'Piwigo Announcements e-Novine';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Ostanite u vezi sa projektom, pretplatite se na Piwigo Announcement e-Novine. Dobijaćete e-mail poruke po izlasku novih verzija (ponekad sa sigurnosnim zakrpama, važno je znati da su dostupne i treba ih što pre ugraditi) te o svim važnijim desavanjima i događanjima u vezi sa projektom. Svega par e-mail poruka godišnje.';
$lang['Subscribe %s'] = 'Pretplatite %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Pretplatite %s na Piwigo English Announcements e-Novine';
$lang['Purge search history'] = 'Očisti istoriju pretraživanja';
$lang['Hide'] = 'Sakrij';
$lang['Operation in progress'] = 'Tretiranje procesa.';
$lang['Please wait...'] = 'Molim sačekajte...';
$lang['Password is missing. Please enter the password.'] = 'Lozinka nedostaje. Molim unesite lozinku.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Potvrda lozinke nedostaje. Molim potvrdite izabranu lozinku.';
$lang['Allow users to edit their own comments'] = 'Dozvoli korisnicima da uređuju svoje komentare';
$lang['Allow users to delete their own comments'] = 'Dozvoli korisnicima da brišu svoje komentare';
$lang['Email administrators when a comment is modified'] = 'Pošalji e-mail administratoru kada je komentar izmenjen';
$lang['Email administrators when a comment is deleted'] = 'Pošalji e-mail administratoru kada je komentar izbrisan';
$lang['Cannot delete the old permalink !'] = 'Stari link se ne može obrisati!';
$lang['Hit'] = 'Pogodak';
$lang['Tools'] = 'Alati';
$lang['Photos'] = 'Fotografije';
$lang['Themes'] = 'Teme';
$lang['Instructions to use Piwigo'] = 'Instrukcije kako da koristite Piwigo';
$lang['Installed Themes'] = 'Instalirane teme';
$lang['Add New Theme'] = 'Dodaj novu temu';
$lang['Forbid this theme to users'] = 'Zabrani ovu temu korisnicima';
$lang['Set as default theme for unregistered and new users'] = 'Postavi kao podrazumevanu temu za neregistrovane i nove korisnike';
$lang['unknown'] = 'nepoznato';
$lang['Upload Photos'] = 'Pošalji fotografije';
$lang['Drop into album'] = 'Baci u kategoriju';
$lang['+ Add an upload box'] = '+ Dodaj kutiju za slanje';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Napravi "%s" directorijum u korenu Vaše Piwigo instalacije';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Dozvoli upis (chmod 777) u "%s" direktorijum u korenu Vaše Piwigo instalcije';
$lang['existing album'] = 'postojeće kategorije';
$lang['create a new album'] = 'napravi novu kategoriju';
$lang['Album name'] = 'Naziv kategorije';
$lang['Album "%s" has been added'] = 'Kategorija "%s" je dodata';
$lang['Uploaded Photos'] = 'Pošalji fotografije';
$lang['%d photos uploaded'] = '%d fotografije poslate';
$lang['Privacy level set to "%s"'] = 'Nivo privatnosti podešen na "%s"';
$lang['Album "%s" now contains %d photos'] = 'Kategorija "%s" sada sadrži %d fotografija';
$lang['Manage this set of %d photos'] = 'Uredi ovaj set %d fotografija';
$lang['Select files'] = 'Izaberi datoteke';
$lang['Everybody'] = 'Svi';
$lang['Who can see these photos?'] = 'Ko može da vidi fotografije?';
$lang['Settings'] = 'Podešenja';
$lang['Resize'] = 'Promeni veličinu';
$lang['Maximum width'] = 'Maksimalna širina';
$lang['pixels'] = 'pikseli';
$lang['Maximum height'] = 'Maksimalna visina';
$lang['Image Quality'] = 'Kvalitet slike';
$lang['Save Settings'] = 'Snimi podešenja';
$lang['Your configuration settings are saved'] = 'Vaša podešenja su sačuvana';
$lang['Active Themes'] = 'Aktivne teme';
$lang['Add write access to the "%s" directory'] = 'Dozvoli upis "%s" direktorijumu';
$lang['Administration Home'] = 'Početna administracije';
$lang['Change Admin Colors'] = 'Promeni administratorske boje';
$lang['Delete this theme'] = 'Obriši ovu temu';
$lang['Directory does not exist'] = 'Direktorijum ne postoji';
$lang['Download,'] = 'Snimi na računar,';
$lang['FTP + Synchronization'] = 'FTP + Sinhronizacija';
$lang['Get Support on Piwigo Forum'] = 'Podrška on Piwigo forumu';
$lang['Help Me'] = 'Pomoć';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Ova tema se ne može aktivirati, jer tema ne postoji: %s';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Ova tema se ne može obrisati, jer druge teme zavise od nje: %s';
$lang['Inactive Themes'] = 'Neaktivne teme';
$lang['Install on your computer,'] = 'Instaliraj na tvom računaru,';
$lang['Make this theme available to users'] = 'Napravi ovu temu dostupnu korisnicima';
$lang['Page end'] = 'Kraj strane';
$lang['Piwigo Uploader'] = 'Piwigo pošiljaoc';
$lang['Read Piwigo Documentation'] = 'Pročitaj Piwigo dokumentaciju';
$lang['Start pLoader and add your photos.'] = 'Pokreni pLoader i dodaj tvoje slike.';
$lang['Switch to clear or dark colors for administration'] = 'Promeni na svetle ili tamne boje za administratora';
$lang['Theme has been successfully installed'] = 'tema je uspešno instalirana';
$lang['Visit Gallery'] = 'Poseti galeriju';
$lang['Visit Piwigo project website'] = 'Poseti stranicu Piwigo projekta';
$lang['Guest Settings'] = 'Podešenja za goste';
$lang['Main Page'] = 'Glavna strana';
$lang['Photo Page'] = 'Foto strana';
$lang['Activate Navigation Bar'] = 'Aktiviraj liniju za navigaciju';
$lang['Activate Navigation Thumbnails'] = 'Aktiviraj povezne sličice za navigaciju';
$lang['Activate icon "%s"'] = 'Aktiviiraj ikonu "%s"';
$lang['Photo Properties'] = 'Osobine slike';
$lang['Allow user customization'] = 'Dozvoli podešavanja korisniku';
$lang['Languages'] = 'Jezici';
$lang['Installed Languages'] = 'Instalirani jezici';
$lang['Add New Language'] = 'Dodaj novi jezik';
$lang['Language has been successfully installed'] = 'Jezik je uspešno instaliran';
$lang['Select:'] = 'Odaberi:';
$lang['None'] = 'Ništa';
$lang['Invert'] = 'Suprotno';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Nemoguće deaktivirati ovu temu, treba Vam bar jedna tema.';
$lang['Webmaster status is required.'] = 'Webmaster status je potreban.';
$lang['Bound Theme'] = 'Povezana tema';
$lang['Allow rating'] = 'Dozvoli rangiranje';
$lang['Select at least one comment'] = 'Odaberi najmanje jedan komentar';
$lang['Active Plugins'] = 'Aktivni dodaci';
$lang['Inactive Plugins'] = 'Neaktivni dodaci';
$lang['Missing Plugins'] = 'Nedostajući dodaci';
$lang['Uninstalled Plugins'] = 'Deinstalirani dodaci';
$lang['By %s'] = 'Od %s';
$lang['Visit plugin site'] = 'Poseti stranicu sa dodacima';
$lang['Active Languages'] = 'Aktivni jezici';
$lang['Delete this language'] = 'Obriši ovaj jezik';
$lang['Forbid this language to users'] = 'Zabrani ovaj jezik za korisnike';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Nemoguće deaktivirati ovaj jezik, prvo odaberite drugi jezik kao podrazumevani.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Nemoguće deaktivirati ovaj jezik, treba Vam najmanje jedan jezik.';
$lang['Inactive Languages'] = 'Neaktivni jezici';
$lang['Make this language available to users'] = 'Omogući ovaj jezik korisnicima';
$lang['Set as default language for unregistered and new users'] = 'Postavi kao podrazumevani jezik za neregistrovane i nove korisnike';
$lang['Add Photos'] = 'Dodaj fotografije';
$lang['The following tag was deleted'] = 'Tekuća oznaka je obrisana';
$lang['Miscellaneous'] = 'Ostalo';
$lang['Virtual Links'] = 'Virtualne veze';
$lang['There is no other language available.'] = 'Drugi jezik nije dostupan.';
$lang['There is no other plugin available.'] = 'Drugi dodatak nije dostupan.';
$lang['There is no other theme available.'] = 'Druga tema nije dostupna.';
$lang['By rank'] = 'Po rangu';
$lang['Manual order'] = 'Ručno poređano';
$lang['Add another set of photos'] = 'Dodaj drugi set fotografija';
 $lang['Order of menubar items has been updated successfully.'] = ' Poredak elemenata u izborniku je uspešno ažuriran.';
$lang['Menu Management'] = 'Izbornik';
$lang['%d of %d photos selected'] = '%d od %d fotografija odabrano';
$lang['%s has been successfully updated.'] = '%s je uspešno ažiran';
$lang['(this tag will be deleted)'] = '(ova oznaka će biti obrisana)';
$lang['... or '] = '... ili';
$lang['Action'] = 'Akcija';
$lang['Activate comments'] = 'Aktivira komentare';
$lang['Activate icon "new" next to albums and pictures'] = 'Aktivira ikonicu "novo" pored albuma i slika';
$lang['Add a criteria'] = 'Dodaj kriterijum';
$lang['Add a filter'] = 'Dodaj filter';
$lang['Add tags'] = 'Dodaj oznake';
$lang['Add to caddie'] = 'Dodaj u fioku';
$lang['Album photos associated to the following albums: %s'] = 'Fotografije albuma povezane sa sledećim albumima: %s';
$lang['Albums automatically sorted'] = 'Albumi automatski poređani';
$lang['All %d photos are selected'] = 'Svih %d fotografija je odabrano';
$lang['All extensions are up to date.'] = 'Sve ekstenzije su ažurne.';
$lang['All languages are up to date.'] = 'Svi jezici su ažurni.';
$lang['All plugins are up to date.'] = 'Svi plaginovi su ažurni.';
$lang['All themes are up to date.'] = 'Sve teme su ažurne.';
$lang['Allowed file types: %s.'] = 'Dozvoljeni tipovi fajlova: %s';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Dogodila se greška u toku raspakivanja. Molimo proverite dozvole na fajlovima Vaše piwigo instalacije.
<br><a href="%s">Kliknite ovde da biste videli zapis greške</a>.';
$lang['An error has occured during upgrade.'] = 'Dogodila se greška u toku nadgradnje.';
$lang['Apply action'] = 'Primeni akciju';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Približna maksimalna rezolucija: %dM piksela (odnosno %dx%d piksela)';
$lang['automatic order'] = 'automatski poredak';
$lang['Average rate'] = 'Prosečna ocena';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Podrazumevano, Piwigo će kreirati novu veličinu prilagođenu web-u od HD verzije (visoke definicije) Vaše fotografije';
$lang['Choose an action'] = 'Izaberi akciju';
$lang['Confirm merge'] = 'Potvrdi pripajanje';
$lang['Create'] = 'Kreiraj';
$lang['Crop'] = 'Iseci';
$lang['Deactivate all'] = 'Isključi sve';
$lang['Default comments order'] = 'Podrazumevani poredak komentara';
$lang['Default photos order'] = 'Podrazumevani poredak fotografija';
$lang['Delete orphan tags'] = 'Obriši napuštene oznake';
$lang['delete photo'] = 'obriši fotografiju';
$lang['display'] = 'prikaži';
$lang['Do you want to activate anyway?'] = 'Da li želite ipak da uključite?';
$lang['Dump Database'] = 'Obriši bazu podataka';
$lang['Duplicates'] = 'Duplikati';
$lang['Error on file "%s" : %s'] = 'Greška u fajlu "%s": %s';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'GREŠKA: OVAJ PLAGIN NEDOSTAJE IAKO JE INSTALIRAN! DEINSTALIRAJTE GA ODMAH.';
$lang['ERROR'] = 'GREŠKA';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif ekstenzija nije dostupna, admin bi trebalo da onemogući njeno korišćenje';
$lang['Extensions Update'] = 'Ažuriranja ekstenzija';
$lang['Failed to write file to disk'] = 'Nije uspelo pisanje fajla na disk';
$lang['File upload stopped by extension'] = 'Otpremanje fajla je zaustavila ekstenzija';
$lang['Follow Orientation'] = 'Prati orjentaciju';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Sledeći plaginovi mogu biti nekompatibilni sa novom verzijom Piwigo-a:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Sledeće teme mogu biti nekompatibilne sa novom verzijom Piwigo-a:';
$lang['Graphics Library'] = 'Biblioteka grafika';
$lang['Height'] = 'Visina';
$lang['hide details'] = 'sakrij detalje';
$lang['I decide to update anyway'] = 'Odlučio sam da ipak ažuriram';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Ako je HD nedostupna i ako je trenutna web-veličina veća od promenjene veličine, Piwigo će ukloniti HD i kreirati smanjenu web-veličinu fotografije.';
$lang['Ignore All'] = 'Ignoriši sve';
$lang['Ignore this update'] = 'Ignoriši ovo ažuriranje';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'U Vašem php.ini fajlu upload_max_filesize(%sB) je veći od post_max_size(%sB), trebalo bi da promenite ovo podešavanje';
$lang['include child albums'] = 'uključi podređene albume';
$lang['Languages which need upgrade'] = 'Jezici kojima treba ažuriranje';
$lang['Last import'] = 'Poslednji uvoz';
$lang['%s photos can not be regenerated'] = '%s fotografija ne može biti regenerisano';
$lang['%s photos have been regenerated'] = '%s fotografija je regenerisano';
$lang['A locked gallery is only visible to administrators'] = 'Zaključana galerija je vidljiva samo administratorima';
$lang['administrators'] = 'administratori';
$lang['Applications'] = 'Aplikacije';
$lang['apply automatic sort order'] = 'primeni automatski poredak';
$lang['Automatic sort order'] = 'Automatski poredak';
$lang['Batch Manager'] = 'Menadžer automatizma';
$lang['cancel manual order'] = 'poništi ručni poredak';
$lang['Cancel'] = 'Odustani';
$lang['Center of interest'] = 'Interesno središte';
$lang['Delete Representant'] = 'Obriši ikonice albuma';
$lang['Gallery unlocked'] = 'Galerija otključana';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Uključi istoriju podataka (Upozorenje: može se premašiti limit memorije na serveru)';
$lang['Learn more'] = 'Nauči više';
$lang['List'] = 'Lista';
$lang['Manage Permissions'] = 'Uredi dozvole';
$lang['manual order'] = 'ručni poredak';
$lang['Maximum file size: %sB.'] = 'Maksimalna veličina fajla: %sB.';
$lang['Merge selected tags'] = 'Spoj odabrane oznake';
$lang['Merge tags'] = 'Spoj oznake';
$lang['Missing a temporary folder'] = 'Nedostaje privremeni direktorijum';
$lang['modified'] = 'izmenjen';
$lang['Move to album'] = 'Premesti u album';
$lang['New Version'] = 'Nova verzija';
$lang['new'] = 'novo';
$lang['No destination tag selected'] = 'Nije odabrana odredišna oznaka';
$lang['No file was uploaded'] = 'Nije poslat ni jedan fajl';
$lang['No photo in the current set.'] = 'Nema fotografija u trenutnom skupu';
$lang['No photo selected, %d photos in current set'] = 'Nema odabranih fotografija, %d fotografija u trenutnom skupu';
$lang['No photos selected, no actions possible.'] = 'Nema odabranih fotografija, nema dozvoljenih akcija';
$lang['No results'] = 'Nema rezultata';
$lang['Not cropped correctly?'] = 'Pogrešno isečeno?';
$lang['Notify administrators when a comment is'] = 'Obavesti administratore kada je komentar';
$lang['Obsolete Plugins'] = 'Zastareli plagin';
$lang['on the %d selected photos'] = 'od %d odabranih fotografija';
$lang['Original Size'] = 'Originalna veličina';
$lang['Orphan tags deleted'] = 'Napuštena oznaka obrisana';
$lang['Pending Comments'] = 'Komentari na čekanju';
$lang['pending validation'] = 'čeka validaciju';
$lang['Photo %s of %s'] = 'Fotografija %s od %s';
$lang['Photo name'] = 'Naziv fotografije';
$lang['Photos generation in progress...'] = 'Generisanje fotografija...';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo ne može preuzeti nadogradnju sa servera';
$lang['Piwigo Update'] = 'Piwigo nadogradnja';
$lang['Predefined filter'] = 'Predefinisani filter';
$lang['Rate'] = 'Ocena';
$lang['Refresh photo set'] = 'Osveži skup fotografija';
$lang['registered users'] = 'registrovani korisnici';
$lang['Remove all filters'] = 'Ukloni sve filtere';
$lang['remove author'] = 'ukloni autora';
$lang['remove creation date'] = 'ukloni datum kreiranja';
$lang['Remove from caddie'] = 'Ukloni iz fioke';
$lang['remove this filter'] = 'ukloni ovaj filter';
$lang['remove title'] = 'ukloni naslov';
$lang['Reset ignored updates'] = 'Resetuj ignorisane nadogradnje';
$lang['Resize after upload'] = 'Promeni veličinu posle slanja';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Vrati podrazumevana podešavanja. Izgubićete podešavanja plaginova!';
$lang['Restore'] = 'Vrati';
$lang['Save manual order'] = 'Sačuvaj ručni poredak';
$lang['Save Template Directory'] = 'Sačuvaj privremeni direktorijum';
$lang['Save visits in history for'] = 'Sačuvaj posete u istoriji za ';
$lang['Searching...'] = 'Traženje...';
$lang['Select an album'] = 'Izaberite album';
$lang['Select at least two tags for merging'] = 'Odaberite najmanje dve oznake za spajanje';
$lang['Select the destination tag'] = 'Odaberite odredišnu oznaku';
$lang['Selection'] = 'Odabir';
$lang['Send connection settings by email'] = 'Pošalji podešavanja veze mejlom';
$lang['Set author'] = 'Postavi autora';
$lang['Set creation date'] = 'Postavi datum kreiranja';
$lang['Set title'] = 'Postavi naslov';
$lang['show details'] = 'prikaži detalje';
$lang['Show menubar'] = 'Prikaži meni bar';
$lang['simple visitors'] = 'obični posetioci';
$lang['Some themes and plugins may be not available yet.'] = 'Neke teme i plaginovi neće biti dostupni odmah.';
$lang['Some upgrades are available for extensions.'] = 'Neke nadogradnje su dostupne za proširenja.';
$lang['Start Upload'] = 'Počni slanje';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Oznake  <em>%s</em> spojene u oznaku <em>%s</em>';
$lang['The original image quality must be a number between %d and %d'] = 'Kvalitet originalne slike mora biti broj između %d i %d';
$lang['The original maximum height must be a number between %d and %d'] = 'Visina originalne slike mora biti broj između %d i %d';
$lang['The original maximum width must be a number between %d and %d'] = 'Širina originalne slike mora biti broj između %d i %d';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Poslati fajl prelazi MAX_FILE_SIZE direktivu koja je specificirana u HTML formi';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Poslati fajl prelazi upload_max_filesize direktivu u php.ini: %sB';
$lang['The uploaded file was only partially uploaded'] = 'Poslati fajl je nije kompletan';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Poslati fajlovi prelaze post_max_size direktivu u php.ini: %sB';
$lang['The whole page'] = 'Kompletna strana';
$lang['The whole set'] = 'Kompletan skup';
$lang['Themes which need upgrade'] = 'Theme koje je potrebno nadograditi';
$lang['This album contains %d photos, added between %s and %s.'] = 'Ovaj album sadrži %d fotografija, dadatih od %s do %s.';
$lang['This album contains %d photos, added on %s.'] = 'Ovaj album sadrži %d fotografija, dodatih %s.';
$lang['This album contains no photo.'] = 'Ovaj album ne sadrži fotografije.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Ovo je bitna nadogradnja, sa <a href="%s"> novim mogućnostima</a>.';
$lang['This is a minor update, with only bug corrections.'] = 'Ovo je manja nadogradnja, sa ispravkama bagova.';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'OVAJ PLAGIN JE SADA DEO PIWIGO JEZGRA! OBRIŠITE GA SADA!';
$lang['This theme was not designed to be directly activated'] = 'Ova tema nije dizajnirana da bude direktno aktivirana';
$lang['Thumbnails generation in progress...'] = 'Generisanje sličica...';
$lang['Two updates are available'] = 'Dve nadogradnje su dostupne';
$lang['Type here the author name'] = 'Unesite ime autora';
$lang['Type here the title'] = 'Unesite naslov';
$lang['Type in a search term'] = 'Unesite pojam za pretragu';
$lang['Unable to dump database.'] = 'Neuspelo brisanje baze.';
$lang['Unknown upload error'] = 'Nepoznata greška slanja';
$lang['Unlock gallery'] = 'Otključaj galeriju';
$lang['Update All'] = 'Nadogradi sve';
$lang['Update Complete'] = 'Nadogradnja završena';
$lang['Update in progress... Please wait.'] = 'Nadogradnja... Molimo sačekajte.';
$lang['Update to Piwigo %s'] = 'Nadogradnja Piwiga %s';
$lang['Updates'] = 'Nadogradnje';
$lang['Visit language site'] = 'Poseti sajt jezika';
$lang['Visit theme site'] = 'Poseti sajt tema';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'UPOZORENJE! Ovaj plagin nije kompatibilan sa trenutnom verzijom Piwiga';
$lang['Web Form'] = 'Web forma';
$lang['Week starts on'] = 'Dan kada počinje sedmica:';
$lang['Who can see this photo?'] = 'Ko može videti fotografiju?';
$lang['Width'] = 'Širina';
$lang['With no album'] = 'Bez albuma';
$lang['With no tag'] = 'Bez oznake';
$lang['With no virtual album'] = 'Bez virtuelnog albuma';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Koristite slanje iz brauzera. Probajte <a href="%s">slanje iz Flash-a</a>.';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Koristite slanje iz Flash-a. Imate problem? Probajte <a href="%s">slanje iz brauzera</a>.';
$lang['You can activate only one mobile theme.'] = 'Možete aktivirati samo jednu pokretnu temu.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Možete nadograditi Piwigo %s direktno, bez nadogradnji na Piwigo %s (preporučeno).';
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'Ne možete postaviti podrazumevani poredak fotografija jer je drugačije podešeno u vašem lokalnom podešavanju.';
$lang['You have %d orphan tags: %s.'] = 'Imate %d napuštenih oznaka: %s.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Označili ste  <i>$conf[\'order_by\']</i> u svom lokalnom podešavanju, ovaj parametar je zastareo, molimo uklonite ga ili ga preimenujte u <i>$conf[\'order_by_custom\']</i>!';
$lang['Zoom'] = 'Uvećaj';
$lang['Delete selected tags'] = 'Obriši odabrane oznake';
$lang['<em>Piwigo for Android</em> application empowers you to connect your Android phone or table to your Piwigo gallery, create some albums and upload several photos at once.'] = '<em>Piwigo for Android</em> aplikacija omogućava Vam da se povežete sa Vašom Piwigo galerijom preko Adroid telefona ili tablet računara, možete da kreirate albume i pošaljete nekoliko slika odjednom.';
$lang['<em>Piwigo for iOS</em> application empowers you to connect to your Piwigo gallery from your iPhone, iPad or iPod Touch, create some albums and upload several photos at once.'] = '<em>Piwigo za iOS</em> aplikacija omogućava Vam da se povežete sa Vašom Piwigo galerijom preko iPhone, iPad ili iPod Touch uređaja, možete da kreirate albume i pošaljete nekoliko slika odjednom.';
$lang['Adobe Photoshop Lightroom is a photography software designed to manage large quantities of digital images and doing post production work.'] = 'Adobe Photoshop Lightroom je softver za fotografije dizajniran da upravlja velikom količinom digitalnih slika i za postprodukciju.';
$lang['Available on'] = 'Dostupno na';
$lang['Delete selected users'] = 'Obriši odabrane korisnike';
$lang['Piwigo for Android'] = 'Piwigo za Android';
$lang['Piwigo for iOS (iPhone, iPad, iPod Touch)'] = 'Piwigo za iOs (iPhone, iPad, iPod Touch)';
$lang['Piwigo Publish plugin for Lightroom'] = 'Piwigo Publish plagin za Ligtroom';
$lang['Piwigo publish plugin for Shotwell'] = 'Piwigo publish plagin za Shotwell';
$lang['The Piwigo publish Plug-in allows you to export and synchronize photos from Lightroom directly to your Piwigo photo gallery.'] = 'Piwigo Publish plagin omogućava Vam da izvezete i sinhronizujete fotografije iz Lightroom-a direktno u Vašu Piwigo foto-galeriju.';
$lang['%u users have automatic permission because they belong to a granted group.'] = '%u korisnici imaju dozvole jer pripadaju grupi kojoj je data dozvola.';
$lang['any visitor can see this album'] = 'bilo koji posetilac može videti ovaj album';
$lang['Aperture is a powerful tool to refine images and manage massive libraries on Mac.'] = 'Aperture je moćan alat za poboljšanje slika i upravljanje velikim bibliotekama na Mac-u.';
$lang['Aperture is designed for professional photographers with iPhoto simplicity.'] = 'Aperture je dizajniran za profesionalne fotografe sa iPhoto jednostavnošću.';
$lang['Delete multiple size images'] = 'Obriši višestruke veličine slika';
$lang['digiKam is an advanced digital photo management free software for Linux, Windows, and MacOSX.'] = 'digiKam je besplatni, napredni menadžer digitalnih fotografija za Linux, Windows i MacOSX';
$lang['digiKam is designed for photographers who want to view, manage, edit, enhance, organize, tag, and share photographs.'] = 'digiKam je dizajniran za fotografe koji žele da pregledaju, upravljaju, urede, poboljšaju, organizuju, označe i dele fotografije.';
$lang['Features include gallery browsing, album creation and photo upload.'] = 'Karakteristike uključuju pregled galerije, kreiranje albuma i slanje fotografija.';
$lang['Generate multiple size images'] = 'Generiši višestruke veličine slika';
$lang['Groups and users'] = 'Grupe i korisnici';
$lang['iPhoto is the default photo manager on MacOSX. The Piwigo export plugin let you create new albums and export your photos directly from iPhoto to your Piwigo photo gallery.'] = 'iPhoto je podrazumevani menadžer fotografijama na MacOSX. Piwigo izvozni dodatak omogućava Vam da kreirate novi album i da izvezete Vaše fotografije direktno iz iPhoto u Vašu Piwigo foto-galeriju.';
$lang['On your Linux, simply install Shotwell with your package manager and the activate Piwigo publishing option.'] = 'Na Linux-u, jednostavno instalirajte Shotwell preko Vašeg menadžera paketa i onda aktivirajte Piwigo opciju objavljivanja.';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Trajni-link %s je prethodno korišćen od strane albuma %s. Obrišite ga prvo iz istorije trajnih linkova';
$lang['Permission granted for groups'] = 'Dozvola pridodata grupama';
$lang['Permission granted for users'] = 'Dozvola data korisnicima';
$lang['Piwigo export plugin for Aperture'] = 'Piwigo izvozni dodatak za Aperture';
$lang['Piwigo export plugin for iPhoto'] = 'Piwigo izvozni dodatak za iPhoto';
$lang['Piwigo publish plugin for digiKam'] = 'Piwigo dodatak za objavljivanje za digiKam';
$lang['ReGalAndroid (RemoteGallery client for Android) is an open source (GPL v3) Piwigo client for the Android platform.'] = 'ReGalAndroid (RemoteGallery klient za Android) je Piwigo klient otvorenog koda (GPL v3) za Adroid platformu.';
$lang['Select groups...'] = 'Odaberi grupe...';
$lang['Select users...'] = 'Odaberi korisnike...';
$lang['Shotwell is an open source digital photo organizer that runs on Linux. It is the default photo manager in Ubuntu and Fedora.'] = 'Shotwell je organizator digitalnih fotografija otvorenog koda za Linux. To je podrazumevani menadžer fotografija u Ubuntu-u i Fedori.';
$lang['The Piwigo export plugin allows you to create albums and export photos.'] = 'Piwigo izvozni dodatak omogućava Vam da kreirate albume i da izvezete fotografije.';
$lang['There is no group in this gallery.'] = 'Ne postoje grupe u ovoj galeriji';
$lang['To export your photos from digiKam to Piwigo, simply install digiKam and the Kipi-plugins.'] = 'Da biste izvezli fotografije iz digiKam-a u Piwigo, samo instalirajte digiKam i the Kipi dodatke';
$lang['visitors need to login and have the appropriate permissions to see this album'] = 'posetioci moraju biti prijavljeni i imati odgovarajuće dozvole da bi videli ovaj album';
$lang['custom'] = 'Po izboru';
$lang['include photos with lower privacy level'] = 'Uključi fotografije sa nižim nivoom privatnosti';
$lang['No group is permitted to see this private album'] = 'Ni jednoj grupi nije dozvoljeno da vidi ovaj privatni album';
$lang['Permission management'] = 'Upravljanje dozvolama';
$lang['Apply watermark if height is bigger than'] = 'Primeni vodeni žig ako je visina veća od';
$lang['Apply watermark if width is bigger than'] = 'Primeni vodeni žig ako je širina veća od ';
$lang['By default, the center of interest is placed in the middle of the photo.'] = 'Podrazumevano, interesni centar je postavljen na sredinu fotografije.';
$lang['For photo sizes with crop, such as "Square", Piwigo will do its best to include the center of interest.'] = 'Za veličine fotografija sa odsecanjem, kao što je "kvadrat", Piwigo će uraditi najbolje što je moguće da uključi interesni centar.';
$lang['Opacity'] = 'Neprovidnost';
$lang['Photo sizes with crop'] = 'Veličina fotografija sa odsecanjem';
$lang['Select a file'] = 'Odaberite fajl';
$lang['Select a zone with your mouse to define a new center of interest.'] = 'Odaberite mišem zonu da bi ste definisali novi interesni centar.';
$lang['The center of interest is the most meaningful zone in the photo.'] = 'Interesni centar je najbitnija zona fotografije.';
$lang['X Position'] = 'X pozicija';
$lang['X Repeat'] = 'X ponavljanja';
$lang['Y Position'] = 'Y pozicija';
$lang['add a new watermark'] = 'dodajte novi vodeni žig';
$lang['bottom left corner'] = 'donji levi ugao';
$lang['bottom right corner'] = 'donji desni ugao';
$lang['middle'] = 'sredina';
$lang['top left corner'] = 'gornji lefi ugao';
$lang['top right corner'] = 'gornji desni ugao';
?>